==> pyconnectwise-0.4.5.tar.gz: pyconnectwise-0.4.5/src/pyconnectwise/endpoints/manage/ProcurementAdjustmentsTypesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.ProcurementAdjustmentsTypesCountEndpoint import \
    ProcurementAdjustmentsTypesCountEndpoint
from pyconnectwise.endpoints.manage.ProcurementAdjustmentsTypesIdEndpoint import ProcurementAdjustmentsTypesIdEndpoint
from pyconnectwise.endpoints.manage.ProcurementAdjustmentsTypesInfoEndpoint import \
    ProcurementAdjustmentsTypesInfoEndpoint
from pyconnectwise.models.manage import AdjustmentType
from pyconnectwise.responses.paginated_response import PaginatedResponse


class ProcurementAdjustmentsTypesEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "types", parent_endpoint=parent_endpoint)

        self.info = self._register_child_endpoint(ProcurementAdjustmentsTypesInfoEndpoint(client, parent_endpoint=self))
        self.count = self._register_child_endpoint(
            ProcurementAdjustmentsTypesCountEndpoint(client, parent_endpoint=self)
        )

    def id(self, id: int) -> ProcurementAdjustmentsTypesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized ProcurementAdjustmentsTypesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            ProcurementAdjustmentsTypesIdEndpoint: The initialized ProcurementAdjustmentsTypesIdEndpoint object.
        """
        child = ProcurementAdjustmentsTypesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[AdjustmentType]:
        """
        Performs a GET request against the /procurement/adjustments/types endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[AdjustmentType]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params),
            AdjustmentType,
            self,
            page,
            page_size,
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[AdjustmentType]:
        """
        Performs a GET request against the /procurement/adjustments/types endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[AdjustmentType]: The parsed response data.
        """
        return self._parse_many(AdjustmentType, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> AdjustmentType:
        """
        Performs a POST request against the /procurement/adjustments/types endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            AdjustmentType: The parsed response data.
        """
        return self._parse_one(AdjustmentType, super()._make_request("POST", data=data, params=params).json())

==> pyconnectwise-0.4.7.tar.gz: pyconnectwise-0.4.7/src/pyconnectwise/endpoints/manage/ProcurementAdjustmentsTypesEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.ProcurementAdjustmentsTypesCountEndpoint import \
    ProcurementAdjustmentsTypesCountEndpoint
from pyconnectwise.endpoints.manage.ProcurementAdjustmentsTypesIdEndpoint import ProcurementAdjustmentsTypesIdEndpoint
from pyconnectwise.endpoints.manage.ProcurementAdjustmentsTypesInfoEndpoint import \
    ProcurementAdjustmentsTypesInfoEndpoint
from pyconnectwise.models.manage import AdjustmentType
from pyconnectwise.responses.paginated_response import PaginatedResponse


class ProcurementAdjustmentsTypesEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "types", parent_endpoint=parent_endpoint)

        self.count = self._register_child_endpoint(
            ProcurementAdjustmentsTypesCountEndpoint(client, parent_endpoint=self)
        )
        self.info = self._register_child_endpoint(ProcurementAdjustmentsTypesInfoEndpoint(client, parent_endpoint=self))

    def id(self, id: int) -> ProcurementAdjustmentsTypesIdEndpoint:
        """
        Sets the ID for this endpoint and returns an initialized ProcurementAdjustmentsTypesIdEndpoint object to move down the chain.

        Parameters:
            id (int): The ID to set.
        Returns:
            ProcurementAdjustmentsTypesIdEndpoint: The initialized ProcurementAdjustmentsTypesIdEndpoint object.
        """
        child = ProcurementAdjustmentsTypesIdEndpoint(self.client, parent_endpoint=self)
        child._id = id
        return child

    def paginated(
        self, page: int, page_size: int, params: dict[str, int | str] = {}
    ) -> PaginatedResponse[AdjustmentType]:
        """
        Performs a GET request against the /procurement/adjustments/types endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[AdjustmentType]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super()._make_request("GET", params=params), AdjustmentType, self, page, page_size, params
        )

    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> list[AdjustmentType]:
        """
        Performs a GET request against the /procurement/adjustments/types endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            list[AdjustmentType]: The parsed response data.
        """
        return self._parse_many(AdjustmentType, super()._make_request("GET", data=data, params=params).json())

    def post(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> AdjustmentType:
        """
        Performs a POST request against the /procurement/adjustments/types endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            AdjustmentType: The parsed response data.
        """
        return self._parse_one(AdjustmentType, super()._make_request("POST", data=data, params=params).json())
